@@ -1,7 +1,7 @@
 #ifndef SQUID_OS_FREEBSD_H
 #define SQUID_OS_FREEBSD_H
 
-#ifdef _SQUID_FREEBSD_
+#if _SQUID_FREEBSD_
 
 /****************************************************************************
  *--------------------------------------------------------------------------*
@@ -9,7 +9,6 @@
  *--------------------------------------------------------------------------*
  ****************************************************************************/
 
-
 #if USE_ASYNC_IO && defined(LINUXTHREADS)
 #define _SQUID_LINUX_THREADS_
 #endif
@@ -32,6 +31,5 @@
 //#define s6_addr16 __u6_addr.__u6_addr16
 #define s6_addr32 __u6_addr.__u6_addr32
 
-
 #endif /* _SQUID_FREEBSD_ */
 #endif /* SQUID_OS_FREEBSD_H */
