@@ -1,7 +1,7 @@
 #ifndef SQUID_OS_OPENBSD_H
 #define SQUID_OS_OPENBSD_H
 
-#ifdef _SQUID_OPENBSD_
+#if _SQUID_OPENBSD_
 
 /****************************************************************************
  *--------------------------------------------------------------------------*
