@@ -1,7 +1,7 @@
 #ifndef SQUID_OS_SUNOS_H
 #define SQUID_OS_SUNOS_H
 
-#ifdef _SQUID_SUNOS_
+#if _SQUID_SUNOS_
 
 /****************************************************************************
  *--------------------------------------------------------------------------*
@@ -9,7 +9,6 @@
  *--------------------------------------------------------------------------*
  ****************************************************************************/
 
-
 /* O_NONBLOCK requires <fcntl.h> to be included first */
 #if HAVE_FCNTL_H
 #include <fcntl.h>
@@ -20,7 +19,5 @@
  */
 #define SQUID_NONBLOCK O_NDELAY
 
-
-
 #endif /* _SQUID_SUNOS_ */
 #endif /* SQUID_OS_SUNOS_H */
