@@ -1,11 +1,10 @@
-#include "config.h"
+#include "squid.h"
 #include "compat/shm.h"
 
 #if _SQUID_FREEBSD_ && (__FreeBSD__ >= 7)
 #include <sys/sysctl.h>
 #endif
 
-
 /*
  * Some systems have filesystem-based resources and interpret segment names
  * as file paths. The so-called 'portable' "/name" format does not work well
