@@ -1,7 +1,3 @@
-#ifndef SQUID_CONFIG_H
-#include "config.h"
-#endif
-
 /*
  * * * * * * * * Legal stuff * * * * * * *
  *
@@ -85,19 +81,17 @@
 #include <netinet/in_systm.h>
 #endif
 
-
 /******************************************************/
 /* Typedefs for missing entries on a system           */
 /******************************************************/
 
-
 /*
  * ISO C99 Standard printf() macros for 64 bit integers
  * On some 64 bit platform, HP Tru64 is one, for printf must be used
  * "%lx" instead of "%llx"
  */
 #ifndef PRId64
-#ifdef _SQUID_MSWIN_		/* Windows native port using MSVCRT */
+#if _SQUID_MSWIN_		/* Windows native port using MSVCRT */
 #define PRId64 "I64d"
 #elif SIZEOF_INT64_T > SIZEOF_LONG
 #define PRId64 "lld"
@@ -107,7 +101,7 @@
 #endif
 
 #ifndef PRIu64
-#ifdef _SQUID_MSWIN_		/* Windows native port using MSVCRT */
+#if _SQUID_MSWIN_		/* Windows native port using MSVCRT */
 #define PRIu64 "I64u"
 #elif SIZEOF_INT64_T > SIZEOF_LONG
 #define PRIu64 "llu"
@@ -117,7 +111,7 @@
 #endif
 
 #ifndef PRIX64
-#ifdef _SQUID_MSWIN_		/* Windows native port using MSVCRT */
+#if _SQUID_MSWIN_		/* Windows native port using MSVCRT */
 #define PRIX64 "I64X"
 #elif SIZEOF_INT64_T > SIZEOF_LONG
 #define PRIX64 "llX"
@@ -126,6 +120,21 @@
 #endif
 #endif
 
+#ifndef PRIuSIZE
+// NP: configure checks for support of %zu and defines where possible
+#if SIZEOF_SIZE_T == 4 && _SQUID_MINGW_
+#define PRIuSIZE "I32u"
+#elif SIZEOF_SIZE_T == 4
+#define PRIuSIZE "u"
+#elif SIZEOF_SIZE_T == 8 && _SQUID_MINGW_
+#define PRIuSIZE "I64u"
+#elif SIZEOF_SIZE_T == 8
+#define PRIuSIZE "lu"
+#else
+#error size_t is not 32-bit or 64-bit
+#endif
+#endif /* PRIuSIZE */
+
 #ifndef HAVE_MODE_T
 typedef unsigned short mode_t;
 #endif
@@ -142,4 +151,12 @@ typedef int socklen_t;
 typedef long mtyp_t;
 #endif
 
+#ifndef NULL
+#if defined(__cplusplus) && HAVE_NULLPTR
+#define NULL nullptr
+#else
+#define NULL 0
+#endif
+#endif
+
 #endif /* SQUID_TYPES_H */
