@@ -22,11 +22,11 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
 */
-#include "config.h"
+#include "squid.h"
 
 #include "digest_common.h"
 
-#ifdef _SQUID_MSWIN_            /* Native Windows port and MinGW */
+#if _SQUID_MSWIN_            /* Native Windows port and MinGW */
 
 #define snprintf _snprintf
 #include <windows.h>
@@ -85,7 +85,6 @@ static int berEncodePasswordData(
     const char    * utf8Pwd2Ptr = NULL;
     int     utf8Pwd2Size = 0;
 
-
     /* Convert objectDN and tag strings from Unicode to UTF-8 */
     utf8ObjSize = strlen(objectDN)+1;
     utf8ObjPtr = objectDN;
@@ -181,7 +180,7 @@ static int berEncodeLoginData(
         err = (ber_printf(requestBer, "{i{", methodIDLen) < 0) ? LDAP_ENCODING_ERROR : 0;
     }
 
-    for (i = 0; !err && i < elemCnt; i++) {
+    for (i = 0; !err && i < elemCnt; ++i) {
         err = (ber_printf(requestBer, "i", methodID[i]) < 0) ? LDAP_ENCODING_ERROR : 0;
     }
 
@@ -393,7 +392,6 @@ static int nmasldap_get_simple_pwd(
     return err;
 }
 
-
 /**********************************************************************
  Attempts to get the Universal Password
 **********************************************************************/
