@@ -1,11 +1,6 @@
-/*
- * $Id$
- */
 #ifndef _MEM_METER_H_
 #define _MEM_METER_H_
 
-#include "config.h"
-
 /* object to track per-action memory usage (e.g. #idle objects) */
 class MemMeter
 {
