@@ -1,7 +1,5 @@
 
 /*
- * $Id$
- *
  * DEBUG: section 63    Low Level Memory Pool Management
  * AUTHOR: Alex Rousskov, Andres Kroonmaa, Robert Collins
  *
@@ -147,7 +145,7 @@ MemChunk::MemChunk(MemPoolChunked *aPool)
     freeList = objCache;
     void **Free = (void **)freeList;
 
-    for (int i = 1; i < pool->chunk_capacity; i++) {
+    for (int i = 1; i < pool->chunk_capacity; ++i) {
         *Free = (void *) ((char *) Free + pool->obj_size);
         void **nextFree = (void **)*Free;
         (void) VALGRIND_MAKE_MEM_NOACCESS(Free, pool->obj_size);
@@ -158,7 +156,7 @@ MemChunk::MemChunk(MemPoolChunked *aPool)
 
     memMeterAdd(pool->getMeter().alloc, pool->chunk_capacity);
     memMeterAdd(pool->getMeter().idle, pool->chunk_capacity);
-    pool->chunkCount++;
+    ++pool->chunkCount;
     lastref = squid_curtime;
     pool->allChunks.insert(this, memCompChunks);
 }
@@ -217,7 +215,7 @@ MemPoolChunked::get()
 {
     void **Free;
 
-    saved_calls++;
+    ++saved_calls;
 
     /* first, try cache */
     if (freeCache) {
@@ -239,7 +237,7 @@ MemPoolChunked::get()
     Free = (void **)chunk->freeList;
     chunk->freeList = *Free;
     *Free = NULL;
-    chunk->inuse_count++;
+    ++chunk->inuse_count;
     chunk->lastref = squid_curtime;
 
     if (chunk->freeList == NULL) {
@@ -480,9 +478,9 @@ MemPoolChunked::getStats(MemPoolStats * stats, int accumulate)
     chunk = Chunks;
     while (chunk) {
         if (chunk->inuse_count == 0)
-            chunks_free++;
+            ++chunks_free;
         else if (chunk->inuse_count < chunk_capacity)
-            chunks_partial++;
+            ++chunks_partial;
         chunk = chunk->next;
     }
 
