@@ -1,6 +1,4 @@
 /*
- * $Id$
- *
  * DEBUG:
  * AUTHOR: Harvest Derived
  *
@@ -31,10 +29,9 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
  *
  */
-#include "config.h"
+#include "squid.h"
 #include "getfullhostname.h"
 
-
 #if HAVE_UNISTD_H
 /* for gethostname() function */
 #include <unistd.h>
