@@ -1,18 +1,17 @@
 #include "squid.h"
-#include "squid-old.h"
-#include "ConfigParser.h"
-#include "ClientDelayConfig.h"
-#include "Parsing.h"
-#include "Store.h"
 #include "acl/Acl.h"
 #include "acl/Gadgets.h"
+#include "ClientDelayConfig.h"
+#include "ConfigParser.h"
+#include "Parsing.h"
+#include "Store.h"
 
 void ClientDelayPool::dump(StoreEntry * entry, unsigned int poolNumberMinusOne) const
 {
     LOCAL_ARRAY(char, nom, 32);
     snprintf(nom, 32, "client_delay_access %d", poolNumberMinusOne + 1);
     dump_acl_access(entry, nom, access);
-    storeAppendPrintf(entry, "client_delay_parameters %d %d %"PRId64"\n", poolNumberMinusOne + 1, rate,highwatermark);
+    storeAppendPrintf(entry, "client_delay_parameters %d %d %" PRId64 "\n", poolNumberMinusOne + 1, rate,highwatermark);
     storeAppendPrintf(entry, "\n");
 }
 
@@ -38,7 +37,7 @@ void ClientDelayConfig::dumpPoolCount(StoreEntry * entry, const char *name) cons
 {
     if (pools.size()) {
         storeAppendPrintf(entry, "%s %d\n", name, (int)pools.size());
-        for (unsigned int i = 0; i < pools.size(); i++)
+        for (unsigned int i = 0; i < pools.size(); ++i)
             pools[i].dump(entry, i);
     }
 }
@@ -46,12 +45,12 @@ void ClientDelayConfig::dumpPoolCount(StoreEntry * entry, const char *name) cons
 void ClientDelayConfig::parsePoolCount()
 {
     if (pools.size()) {
-        debugs(3, 0, "parse_client_delay_pool_count: multiple client_delay_pools lines, aborting all previous client_delay_pools config");
+        debugs(3, DBG_CRITICAL, "parse_client_delay_pool_count: multiple client_delay_pools lines, aborting all previous client_delay_pools config");
         clean();
     }
     unsigned short pools_;
     ConfigParser::ParseUShort(&pools_);
-    for (int i = 0; i < pools_; i++) {
+    for (int i = 0; i < pools_; ++i) {
         pools.push_back(ClientDelayPool());
     }
 }
@@ -62,11 +61,11 @@ void ClientDelayConfig::parsePoolRates()
     ConfigParser::ParseUShort(&pool);
 
     if (pool < 1 || pool > pools.size()) {
-        debugs(3, 0, "parse_client_delay_pool_rates: Ignoring pool " << pool << " not in 1 .. " << pools.size());
+        debugs(3, DBG_CRITICAL, "parse_client_delay_pool_rates: Ignoring pool " << pool << " not in 1 .. " << pools.size());
         return;
     }
 
-    pool--;
+    --pool;
 
     pools[pool].rate = GetInteger();
     pools[pool].highwatermark = GetInteger64();
@@ -79,7 +78,7 @@ void ClientDelayConfig::parsePoolAccess(ConfigParser &parser)
     ConfigParser::ParseUShort(&pool);
 
     if (pool < 1 || pool > pools.size()) {
-        debugs(3, 0, "parse_client_delay_pool_rates: Ignoring pool " << pool << " not in 1 .. " << pools.size());
+        debugs(3, DBG_CRITICAL, "parse_client_delay_pool_rates: Ignoring pool " << pool << " not in 1 .. " << pools.size());
         return;
     }
 
@@ -89,7 +88,7 @@ void ClientDelayConfig::parsePoolAccess(ConfigParser &parser)
 
 void ClientDelayConfig::clean()
 {
-    for (unsigned int i = 0; i < pools.size(); i++) {
+    for (unsigned int i = 0; i < pools.size(); ++i) {
         aclDestroyAccessList(&pools[i].access);
     }
 }
