@@ -1,7 +1,4 @@
-
 /*
- * $Id$
- *
  * SQUID Web Proxy Cache          http://www.squid-cache.org/
  * ----------------------------------------------------------
  *
@@ -34,6 +31,8 @@
 #ifndef SQUID_AIODISKIOMODULE_H
 #define SQUID_AIODISKIOMODULE_H
 
+#if USE_DISKIO_AIO
+
 #include "DiskIO/DiskIOModule.h"
 
 class AIODiskIOModule : public DiskIOModule
@@ -51,4 +50,5 @@ private:
     static AIODiskIOModule Instance;
 };
 
+#endif /* USE_DISKIO_AIO */
 #endif /* SQUID_AIODISKIOMODULE_H */
