@@ -1,7 +1,5 @@
 
 /*
- * $Id$
- *
  * DEBUG: section 32    Asynchronous Disk I/O
  * AUTHOR: Pete Bentley <pete@demon.net>
  * AUTHOR: Stewart Forster <slf@connect.com.au>
@@ -34,7 +32,7 @@
  *
  */
 
-#include "squid-old.h"
+#include "squid.h"
 #include "DiskThreads.h"
 #include "Store.h"
 #include "fde.h"
@@ -110,7 +108,7 @@ aioCancel(int fd)
             AIOCB *callback = ctrlp->done_handler;
             void *cbdata;
             ctrlp->done_handler = NULL;
-            debugs(32, 1, "this be aioCancel. Danger ahead!");
+            debugs(32, DBG_IMPORTANT, "this be aioCancel. Danger ahead!");
 
             if (cbdataReferenceValidDone(ctrlp->done_handler_data, &cbdata))
                 callback(fd, cbdata, NULL, -2, -2);
@@ -129,7 +127,6 @@ aioCancel(int fd)
     }
 }
 
-
 void
 aioWrite(int fd, off_t offset, char *bufp, size_t len, AIOCB * callback, void *callback_data, FREE * free_func)
 {
@@ -158,7 +155,6 @@ aioWrite(int fd, off_t offset, char *bufp, size_t len, AIOCB * callback, void *c
     dlinkAdd(ctrlp, &ctrlp->node, &used_list);
 }				/* aioWrite */
 
-
 void
 aioRead(int fd, off_t offset, size_t len, AIOCB * callback, void *callback_data)
 {
