@@ -1,13 +1,11 @@
-
 /*
- * $Id$
- *
  * DEBUG: section 47    Store Directory Routines
  */
 
 #include "squid.h"
 #include "MmappedFile.h"
 #include "MmappedIOStrategy.h"
+#include "unlinkd.h"
 
 bool
 MmappedIOStrategy::shedLoad()
@@ -37,9 +35,5 @@ MmappedIOStrategy::unlinkdUseful() const
 void
 MmappedIOStrategy::unlinkFile(char const *path)
 {
-#if USE_UNLINKD
     unlinkdUnlink(path);
-#else
-    ::unlink(path);
-#endif
 }
