@@ -1,6 +1,4 @@
 /*
- * $Id$
- *
  *
  * SQUID Web Proxy Cache          http://www.squid-cache.org/
  * ----------------------------------------------------------
@@ -33,10 +31,12 @@
 #ifndef SQUID_HTTPREQUESTMETHOD_H
 #define SQUID_HTTPREQUESTMETHOD_H
 
-#include "squid.h"
-#include <iosfwd>
 #include "SquidString.h"
 
+class SquidConfig;
+
+#include <iosfwd>
+
 enum _method_t {
     METHOD_NONE,		/* 000 */
     METHOD_GET,			/* 001 */
@@ -72,7 +72,6 @@ enum _method_t {
     METHOD_ENUM_END  // MUST be last, (yuck) this is used as an array-initialization index constant!
 };
 
-
 /**
  * This class represents an HTTP Request METHOD
  * - i.e. PUT, POST, GET etc.
