@@ -1,7 +1,5 @@
 
 /*
- * $Id$
- *
  * DEBUG: section 77    Delay Pools
  * AUTHOR: Robert Collins <robertc@squid-cache.org>
  * Based upon original delay pools code by
@@ -36,13 +34,10 @@
  *
  * Copyright (c) 2003, Robert Collins <robertc@squid-cache.org>
  */
-
-#include "config.h"
-
 #ifndef NULLDELAYID_H
 #define NULLDELAYID_H
-#if DELAY_POOLS
-#include "squid.h"
+
+#if USE_DELAY_POOLS
 #include "RefCount.h"
 #include "DelayIdComposite.h"
 
