@@ -1,7 +1,5 @@
 
 /*
- * $Id$
- *
  *
  * SQUID Web Proxy Cache          http://www.squid-cache.org/
  * ----------------------------------------------------------
@@ -34,6 +32,7 @@
 #ifndef SQUID_STORECLIENT_H
 #define SQUID_STORECLIENT_H
 
+#include "dlink.h"
 #include "StoreIOBuffer.h"
 #include "StoreIOState.h"
 
@@ -99,7 +98,6 @@ public:
     StoreIOBuffer copyInto;
 
 private:
-    CBDATA_CLASS(store_client);
     void fileRead();
     void scheduleDiskRead();
     void scheduleMemRead();
@@ -122,9 +120,16 @@ public:
         STCB *callback_handler;
         void *callback_data;
     } _callback;
+
+private:
+    CBDATA_CLASS(store_client);
 };
 
-SQUIDCEXTERN void storeClientCopy(store_client *, StoreEntry *, StoreIOBuffer, STCB *, void *);
-
+void storeClientCopy(store_client *, StoreEntry *, StoreIOBuffer, STCB *, void *);
+store_client* storeClientListAdd(StoreEntry * e, void *data);
+int storeClientCopyPending(store_client *, StoreEntry * e, void *data);
+int storeUnregister(store_client * sc, StoreEntry * e, void *data);
+int storePendingNClients(const StoreEntry * e);
+int storeClientIsThisAClient(store_client * sc, void *someClient);
 
 #endif /* SQUID_STORECLIENT_H */
