@@ -1,7 +1,5 @@
 
 /*
- * $Id$
- *
  * DEBUG: section 20    Storage Manager Swapfile Metadata
  *
  * SQUID Web Proxy Cache          http://www.squid-cache.org/
@@ -32,7 +30,7 @@
  *
  */
 
-#include "squid-old.h"
+#include "squid.h"
 #include "StoreMetaSTDLFS.h"
 #include "Store.h"
 #include "MemObject.h"
