@@ -1,7 +1,5 @@
 
 /*
- * $Id$
- *
  * DEBUG: section 53    AS Number handling
  * AUTHOR: Duane Wessels, Kostas Anagnostakis
  *
@@ -33,21 +31,25 @@
  *
  */
 
-#include "squid-old.h"
-#include "mgr/Registration.h"
-#include "radix.h"
-#include "HttpRequest.h"
-#include "StoreClient.h"
-#include "Store.h"
+#include "squid.h"
 #include "acl/Acl.h"
 #include "acl/Asn.h"
 #include "acl/Checklist.h"
-#include "acl/SourceAsn.h"
 #include "acl/DestinationAsn.h"
 #include "acl/DestinationIp.h"
-#include "HttpReply.h"
-#include "ipcache.h"
+#include "acl/SourceAsn.h"
+#include "cache_cf.h"
 #include "forward.h"
+#include "HttpReply.h"
+#include "HttpRequest.h"
+#include "ipcache.h"
+#include "mgr/Registration.h"
+#include "radix.h"
+#include "RequestFlags.h"
+#include "SquidConfig.h"
+#include "Store.h"
+#include "StoreClient.h"
+#include "StoreClient.h"
 #include "wordlist.h"
 
 #define WHOIS_PORT 43
@@ -55,7 +57,6 @@
 
 /* BEGIN of definitions for radix tree entries */
 
-
 /* 32/128 bits address in memory with length */
 class m_ADDR
 {
@@ -113,7 +114,6 @@ static void asnCacheStart(int as);
 
 static STCB asHandleReply;
 
-
 #if defined(__cplusplus)
 extern "C" {
 #endif
@@ -201,12 +201,14 @@ CBDATA_TYPE(ASState);
 void
 asnInit(void)
 {
-    static int inited = 0;
+    static bool inited = false;
     squid_max_keylen = 40;
     CBDATA_INIT_TYPE(ASState);
 
-    if (0 == inited++)
+    if (!inited) {
+        inited = true;
         squid_rn_init();
+    }
 
     squid_rn_inithead(&AS_tree_head, 8);
 
@@ -230,7 +232,6 @@ asnStats(StoreEntry * sentry)
 
 /* PRIVATE */
 
-
 static void
 asnCacheStart(int as)
 {
@@ -248,7 +249,7 @@ asnCacheStart(int as)
     asState->request = HTTPMSGLOCK(req);
 
     if ((e = storeGetPublic(asres, METHOD_GET)) == NULL) {
-        e = storeCreateEntry(asres, asres, request_flags(), METHOD_GET);
+        e = storeCreateEntry(asres, asres, RequestFlags(), METHOD_GET);
         asState->sc = storeClientListAdd(e, asState);
         FwdState::fwdStart(Comm::ConnectionPointer(), e, asState->request);
     } else {
@@ -293,11 +294,11 @@ asHandleReply(void *data, StoreIOBuffer result)
         asStateFree(asState);
         return;
     } else if (result.flags.error) {
-        debugs(53, 1, "asHandleReply: Called with Error set and size=" << (unsigned int) result.length);
+        debugs(53, DBG_IMPORTANT, "asHandleReply: Called with Error set and size=" << (unsigned int) result.length);
         asStateFree(asState);
         return;
     } else if (HTTP_OK != e->getReply()->sline.status) {
-        debugs(53, 1, "WARNING: AS " << asState->as_number << " whois request failed");
+        debugs(53, DBG_IMPORTANT, "WARNING: AS " << asState->as_number << " whois request failed");
         asStateFree(asState);
         return;
     }
@@ -310,9 +311,9 @@ asHandleReply(void *data, StoreIOBuffer result)
 
     while ((size_t)(s - buf) < result.length + asState->reqofs && *s != '\0') {
         while (*s && xisspace(*s))
-            s++;
+            ++s;
 
-        for (t = s; *t; t++) {
+        for (t = s; *t; ++t) {
             if (xisspace(*t))
                 break;
         }
@@ -388,15 +389,12 @@ asStateFree(void *data)
     cbdataFree(asState);
 }
 
-
 /**
  * add a network (addr, mask) to the radix tree, with matching AS number
  */
 static int
 asnAddNet(char *as_string, int as_number)
 {
-    rtentry_t *e;
-
     struct squid_radix_node *rn;
     CbDataList<int> **Tail = NULL;
     CbDataList<int> *q = NULL;
@@ -430,9 +428,7 @@ asnAddNet(char *as_string, int as_number)
 
     debugs(53, 3, "asnAddNet: called for " << addr << "/" << mask );
 
-    e = (rtentry_t *)xmalloc(sizeof(rtentry_t));
-
-    memset(e, '\0', sizeof(rtentry_t));
+    rtentry_t *e = (rtentry_t *)xcalloc(1, sizeof(rtentry_t));
 
     e->e_addr.addr = addr;
 
@@ -509,8 +505,6 @@ destroyRadixNodeInfo(as_info * e_info)
         data = data->next;
         delete prev;
     }
-
-    delete data;
 }
 
 static int
@@ -628,21 +622,20 @@ ACLSourceASNStrategy::Instance()
 
 ACLSourceASNStrategy ACLSourceASNStrategy::Instance_;
 
-
 int
 ACLDestinationASNStrategy::match (ACLData<MatchType> * &data, ACLFilledChecklist *checklist)
 {
     const ipcache_addrs *ia = ipcache_gethostbyname(checklist->request->GetHost(), IP_LOOKUP_IF_MISS);
 
     if (ia) {
-        for (int k = 0; k < (int) ia->count; k++) {
+        for (int k = 0; k < (int) ia->count; ++k) {
             if (data->match(ia->in_addrs[k]))
                 return 1;
         }
 
         return 0;
 
-    } else if (!checklist->request->flags.destinationIPLookedUp()) {
+    } else if (!checklist->request->flags.destinationIpLookedUp) {
         /* No entry in cache, lookup not attempted */
         /* XXX FIXME: allow accessing the acl name here */
         debugs(28, 3, "asnMatchAcl: Can't yet compare '" << "unknown" /*name*/ << "' ACL for '" << checklist->request->GetHost() << "'");
