@@ -1,9 +1,9 @@
-#include "squid-old.h"
+#include "squid.h"
 #include "acl/PeerName.h"
+#include "acl/RegexData.h"
 #include "acl/StringData.h"
 #include "acl/Checklist.h"
-
-
+#include "CachePeer.h"
 
 int
 ACLPeerNameStrategy::match (ACLData<MatchType> * &data, ACLFilledChecklist *checklist)
