@@ -1,9 +1,4 @@
-
-/*
- * $Id$
- */
-
-#include "squid-old.h"
+#include "squid.h"
 #include "acl/SslError.h"
 #include "acl/SslErrorData.h"
 #include "acl/Checklist.h"
@@ -11,7 +6,7 @@
 int
 ACLSslErrorStrategy::match (ACLData<MatchType> * &data, ACLFilledChecklist *checklist)
 {
-    return data->match (checklist->ssl_error);
+    return data->match (checklist->sslErrors);
 }
 
 ACLSslErrorStrategy *
