@@ -1,6 +1,4 @@
 /*
- * $Id$
- *
  * DEBUG: section 28    Access Control
  * AUTHOR: Duane Wessels
  *
@@ -34,9 +32,10 @@
  * Copyright (c) 2003, Robert Collins <robertc@squid-cache.org>
  */
 
-#include "squid-old.h"
+#include "squid.h"
 #include "acl/UserData.h"
 #include "acl/Checklist.h"
+#include "Debug.h"
 #include "wordlist.h"
 #include "ConfigParser.h"
 
@@ -160,7 +159,6 @@ ACLUserData::parse()
     }
 }
 
-
 bool
 ACLUserData::empty() const
 {
