@@ -1,12 +1,10 @@
 #include "squid.h"
-#include "structs.h"
-
-#include "ConfigParser.h"
 #include "acl/Gadgets.h"
 #include "adaptation/AccessRule.h"
 #include "adaptation/Service.h"
 #include "adaptation/ServiceGroups.h"
-
+#include "ConfigParser.h"
+#include "Debug.h"
 
 int Adaptation::AccessRule::LastId = 0;
 
@@ -32,25 +30,24 @@ Adaptation::AccessRule::finalize()
         debugs(93,7, HERE << "no service group: " << groupId);
         // try to add a one-service group
         if (FindService(groupId) != NULL) {
-            ServiceGroup *g = new SingleService(groupId);
+            ServiceGroupPointer g = new SingleService(groupId);
             g->finalize(); // explicit groups were finalized before rules
             AllGroups().push_back(g);
         }
     }
 
     if (!group()) {
-        debugs(93,0, "ERROR: Unknown adaptation service or group name: '" <<
+        debugs(93, DBG_CRITICAL, "ERROR: Unknown adaptation service or group name: '" <<
                groupId << "'"); // TODO: fail on failures
     }
 }
 
-Adaptation::ServiceGroup *
+Adaptation::ServiceGroupPointer
 Adaptation::AccessRule::group()
 {
     return FindGroup(groupId);
 }
 
-
 Adaptation::AccessRules &
 Adaptation::AllRules()
 {
