@@ -2,7 +2,7 @@
  * DEBUG: section 93    Adaptation
  */
 
-#include "squid-old.h"
+#include "squid.h"
 #include "adaptation/Answer.h"
 #include "adaptation/Config.h"
 #include "adaptation/Iterator.h"
@@ -14,7 +14,6 @@
 #include "HttpReply.h"
 #include "HttpMsg.h"
 
-
 Adaptation::Iterator::Iterator(
     HttpMsg *aMsg, HttpRequest *aCause,
     const ServiceGroupPointer &aGroup):
@@ -57,6 +56,12 @@ void Adaptation::Iterator::step()
         return;
     }
 
+    HttpRequest *request = dynamic_cast<HttpRequest*>(theMsg);
+    if (!request)
+        request = theCause;
+    assert(request);
+    request->clearError();
+
     if (iterations > Adaptation::Config::service_iteration_limit) {
         debugs(93,DBG_CRITICAL, "Adaptation iterations limit (" <<
                Adaptation::Config::service_iteration_limit << ") exceeded:\n" <<
