@@ -1,29 +1,22 @@
 #ifndef SQUID_ICAPHISTORY_H
 #define SQUID_ICAPHISTORY_H
 
-#include "RefCount.h"
-#include "HttpHeader.h"
 #include "enums.h"
+#include "RefCount.h"
+#include "SquidString.h"
 
-namespace Adaptation {
-namespace Icap {
+namespace Adaptation
+{
+namespace Icap
+{
 
 /// collects information about ICAP processing related to an HTTP transaction
-class History: public RefCountable {
+class History: public RefCountable
+{
 public:
     typedef RefCount<History> Pointer;
 
     History();
-    History(const History& ih);
-
-    ~History();
-
-    History& operator=(const History& ih);
-
-    ///store the last reply header from ICAP server
-    void setIcapLastHeader(const HttpHeader * lih);
-    ///merge new header and stored one
-    void mergeIcapHeaders(const HttpHeader * lih);
 
     /// record the start of an ICAP processing interval
     void start(const char *context);
@@ -33,8 +26,6 @@ public:
     /// returns the total time of all ICAP processing intervals
     int processingTime() const;
 
-    HttpHeader mergeOfIcapHeaders; ///< Merge of REQMOD and RESPMOD responses. If both responses contain the header, the one from the last response will be used
-    HttpHeader lastIcapHeader; ///< Last received reply from ICAP server
     String rfc931; ///< the username from ident
 #if USE_SSL
     String ssluser; ///< the username from SSL
@@ -45,8 +36,6 @@ public:
     size_t req_sz; ///< the request size
 
 private:
-    void assign(const History &);
-
     int currentTime() const; ///< time since current start or zero
 
     timeval currentStart; ///< when the current processing interval started
