@@ -2,7 +2,7 @@
  * DEBUG: section 93    ICAP (RFC 3507) Client
  */
 
-#include "squid-old.h"
+#include "squid.h"
 #include "AccessLogEntry.h"
 #include "adaptation/Answer.h"
 #include "adaptation/History.h"
@@ -19,11 +19,13 @@
 #include "ChunkedCodingParser.h"
 #include "comm.h"
 #include "comm/Connection.h"
-#include "HttpMsg.h"
-#include "HttpRequest.h"
-#include "HttpReply.h"
-#include "SquidTime.h"
 #include "err_detail_type.h"
+#include "HttpHeaderTools.h"
+#include "HttpMsg.h"
+#include "HttpReply.h"
+#include "HttpRequest.h"
+#include "SquidTime.h"
+#include "URL.h"
 
 // flow and terminology:
 //     HTTP| --> receive --> encode --> write --> |network
@@ -715,8 +717,6 @@ void Adaptation::Icap::ModXact::disableBypass(const char *reason, bool including
     }
 }
 
-
-
 // note that allocation for echoing is done in handle204NoContent()
 void Adaptation::Icap::ModXact::maybeAllocateHttpMsg()
 {
@@ -1249,14 +1249,16 @@ void Adaptation::Icap::ModXact::swanSong()
     Adaptation::Icap::Xaction::swanSong();
 }
 
-void prepareLogWithRequestDetails(HttpRequest *, AccessLogEntry *);
+void prepareLogWithRequestDetails(HttpRequest *, AccessLogEntry::Pointer &);
 
 void Adaptation::Icap::ModXact::finalizeLogInfo()
 {
     HttpRequest * request_ = NULL;
+    HttpRequest * adapted_request_ = NULL;
     HttpReply * reply_ = NULL;
-    if (!(request_ = dynamic_cast<HttpRequest*>(adapted.header))) {
-        request_ = (virgin.cause? virgin.cause: dynamic_cast<HttpRequest*>(virgin.header));
+    request_ = (virgin.cause? virgin.cause: dynamic_cast<HttpRequest*>(virgin.header));
+    if (!(adapted_request_ = dynamic_cast<HttpRequest*>(adapted.header))) {
+        adapted_request_ = request_;
         reply_ = dynamic_cast<HttpReply*>(adapted.header);
     }
 
@@ -1270,6 +1272,8 @@ void Adaptation::Icap::ModXact::finalizeLogInfo()
     al.cache.caddr = request_->client_addr;
 
     al.request = HTTPMSGLOCK(request_);
+    al.adapted_request = HTTPMSGLOCK(adapted_request_);
+
     if (reply_)
         al.reply = HTTPMSGLOCK(reply_);
     else
@@ -1313,11 +1317,10 @@ void Adaptation::Icap::ModXact::finalizeLogInfo()
         packerClean(&p);
         mb.clean();
     }
-    prepareLogWithRequestDetails(request_, &al);
+    prepareLogWithRequestDetails(adapted_request_, alep);
     Xaction::finalizeLogInfo();
 }
 
-
 void Adaptation::Icap::ModXact::makeRequestHeaders(MemBuf &buf)
 {
     char ntoabuf[MAX_IPSTRLEN];
@@ -1364,7 +1367,6 @@ void Adaptation::Icap::ModXact::makeRequestHeaders(MemBuf &buf)
         }
     }
 
-
     buf.Printf("Encapsulated: ");
 
     MemBuf httpBuf;
@@ -1784,7 +1786,6 @@ void Adaptation::Icap::ModXact::makeAdaptedBodyPipe(const char *what)
            adapted.body_pipe << " pipe");
 }
 
-
 // TODO: Move SizedEstimate and Preview elsewhere
 
 Adaptation::Icap::SizedEstimate::SizedEstimate()
@@ -1813,8 +1814,6 @@ uint64_t Adaptation::Icap::SizedEstimate::size() const
     return static_cast<uint64_t>(theData);
 }
 
-
-
 Adaptation::Icap::VirginBodyAct::VirginBodyAct(): theStart(0), theState(stUndecided)
 {}
 
@@ -1846,7 +1845,6 @@ uint64_t Adaptation::Icap::VirginBodyAct::offset() const
     return static_cast<uint64_t>(theStart);
 }
 
-
 Adaptation::Icap::Preview::Preview(): theWritten(0), theAd(0), theState(stDisabled)
 {}
 
@@ -1923,6 +1921,17 @@ void Adaptation::Icap::ModXact::detailError(int errDetail)
         request->detailError(ERR_ICAP_FAILURE, errDetail);
 }
 
+void Adaptation::Icap::ModXact::clearError()
+{
+    HttpRequest *request = dynamic_cast<HttpRequest*>(adapted.header);
+    // if no adapted request, update virgin (and inherit its properties later)
+    if (!request)
+        request = const_cast<HttpRequest*>(&virginRequest());
+
+    if (request)
+        request->clearError();
+}
+
 /* Adaptation::Icap::ModXactLauncher */
 
 Adaptation::Icap::ModXactLauncher::ModXactLauncher(HttpMsg *virginHeader, HttpRequest *virginCause, Adaptation::ServicePointer aService):
