@@ -1,6 +1,4 @@
 /*
- * $Id$
- *
  * DEBUG: section 29    Authenticator
  * AUTHOR:  Robert Collins
  *
@@ -35,6 +33,8 @@
 #include "squid.h"
 #include "auth/Config.h"
 #include "auth/UserRequest.h"
+#include "Debug.h"
+#include "globals.h"
 
 Auth::ConfigVector Auth::TheConfig;
 
@@ -45,7 +45,7 @@ Auth::ConfigVector Auth::TheConfig;
  * It may be a cached AuthUser or a new Unauthenticated object.
  * It may also be NULL reflecting that no user could be created.
  */
-AuthUserRequest::Pointer
+Auth::UserRequest::Pointer
 Auth::Config::CreateAuthUser(const char *proxy_auth)
 {
     assert(proxy_auth != NULL);
