@@ -26,7 +26,7 @@ public:
     virtual int authenticated() const;
     virtual void authenticate(HttpRequest * request, ConnStateData *conn, http_hdr_type type);
     virtual Auth::Direction module_direction();
-    virtual void module_start(RH *, void *);
+    virtual void module_start(AUTHCB *, void *);
 
 private:
     static HLPCB HandleReply;
