@@ -4,6 +4,7 @@
 #include "auth/digest/UserRequest.h"
 #include "auth/State.h"
 #include "charset.h"
+#include "HttpHeaderTools.h"
 #include "HttpReply.h"
 #include "HttpRequest.h"
 #include "SquidTime.h"
@@ -19,7 +20,10 @@ Auth::Digest::UserRequest::UserRequest() :
         uri(NULL),
         response(NULL),
         nonce(NULL)
-{}
+{
+    memset(nc, 0, sizeof(nc));
+    memset(&flags, 0, sizeof(flags));
+}
 
 /**
  * Delete the digest request structure.
@@ -279,8 +283,10 @@ Auth::Digest::UserRequest::HandleReply(void *data, char *reply)
     debugs(29, 9, HERE << "{" << (reply ? reply : "<NULL>") << "}");
 
     if (reply) {
-        if ((t = strchr(reply, ' ')))
-            *t++ = '\0';
+        if ((t = strchr(reply, ' '))) {
+            *t = '\0';
+            ++t;
+        }
 
         if (*reply == '\0' || *reply == '\n')
             reply = NULL;
