@@ -1,4 +1,4 @@
-#include "config.h"
+#include "squid.h"
 #include "base/RunnersRegistry.h"
 #include <list>
 #include <map>
@@ -44,7 +44,6 @@ void
 DeactivateRegistered(const RunnerRegistry &registryId)
 {
     Runners &runners = GetRunners(registryId);
-    typedef Runners::iterator RRI;
     while (!runners.empty()) {
         delete runners.back();
         runners.pop_back();
