@@ -29,8 +29,8 @@ static int64_t lost_conn = 0;
 Comm::Connection::~Connection()
 {
     if (fd >= 0) {
-        debugs(5, DBG_CRITICAL, "BUG: Orphan Comm::Connection: " << *this);
-        debugs(5, DBG_CRITICAL, "NOTE: " << ++lost_conn << " Orphans since last started.");
+        debugs(5, 4, "BUG #3329: Orphan Comm::Connection: " << *this);
+        debugs(5, 4, "NOTE: " << ++lost_conn << " Orphans since last started.");
         close();
     }
 
