@@ -1,13 +1,9 @@
-/*
- * $Id$
- */
-#include "config.h"
+#include "squid.h"
 #include "dlink.h"
 
 /* dlink are Mem-pooled */
 #include "MemPool.h"
 
-
 dlink_list ClientActiveRequests;
 
 MemAllocator *dlink_node_pool = NULL;
