@@ -1,7 +1,5 @@
 
 /*
- * $Id$
- *
  * DEBUG: section 51    Filedescriptor Functions
  * AUTHOR: Duane Wessels
  *
@@ -33,12 +31,14 @@
  *
  */
 
-#include "squid-old.h"
+#include "squid.h"
 #include "comm/Loops.h"
-#include "fde.h"
-#include "SquidTime.h"
 #include "Debug.h"
-
+#include "fd.h"
+#include "fde.h"
+#include "globals.h"
+#include "profiler/Profiler.h"
+#include "SquidTime.h"
 
 // Solaris and possibly others lack MSG_NOSIGNAL optimization
 // TODO: move this into compat/? Use a dedicated compat file to avoid dragging
@@ -213,7 +213,7 @@ fd_open(int fd, unsigned int type, const char *desc)
     F = &fd_table[fd];
 
     if (F->flags.open) {
-        debugs(51, 1, "WARNING: Closing open FD " << std::setw(4) << fd);
+        debugs(51, DBG_IMPORTANT, "WARNING: Closing open FD " << std::setw(4) << fd);
         fd_close(fd);
     }
 
@@ -308,7 +308,7 @@ fdDumpOpen(void)
         if (i == fileno(debug_log))
             continue;
 
-        debugs(51, 1, "Open FD "<< std::left<< std::setw(10) <<
+        debugs(51, DBG_IMPORTANT, "Open FD "<< std::left<< std::setw(10) <<
                (F->bytes_read && F->bytes_written ? "READ/WRITE" :
                 F->bytes_read ? "READING" : F->bytes_written ? "WRITING" :
                 "UNSTARTED")  <<
@@ -362,13 +362,13 @@ fdAdjustReserved(void)
 
     if (newReserve > x) {
         /* perhaps this should be fatal()? -DW */
-        debugs(51, 0, "WARNING: This machine has a serious shortage of filedescriptors.");
+        debugs(51, DBG_CRITICAL, "WARNING: This machine has a serious shortage of filedescriptors.");
         newReserve = x;
     }
 
     if (Squid_MaxFD - newReserve < min(256, Squid_MaxFD / 2))
         fatalf("Too few filedescriptors available in the system (%d usable of %d).\n", Squid_MaxFD - newReserve, Squid_MaxFD);
 
-    debugs(51, 0, "Reserved FD adjusted from " << RESERVED_FD << " to " << newReserve << " due to failures");
+    debugs(51, DBG_CRITICAL, "Reserved FD adjusted from " << RESERVED_FD << " to " << newReserve << " due to failures");
     RESERVED_FD = newReserve;
 }
