@@ -1,7 +1,5 @@
 
 /*
- * $Id$
- *
  * DEBUG: none          FDE
  * AUTHOR: Robert Collins
  *
@@ -33,11 +31,14 @@
  *
  */
 
-#include "squid-old.h"
+#include "squid.h"
+#include "comm.h"
 #include "fde.h"
+#include "globals.h"
 #include "SquidTime.h"
 #include "Store.h"
-#include "comm.h"
+
+fde *fde::Table = NULL;
 
 bool
 fde::readPending(int fdNumber)
@@ -99,7 +100,7 @@ fde::DumpStats (StoreEntry *dumpEntry)
     storeAppendPrintf(dumpEntry, "---- ------ ---- -------- -------- --------------------- ------------------------------\n");
 #endif
 
-    for (i = 0; i < Squid_MaxFD; i++) {
+    for (i = 0; i < Squid_MaxFD; ++i) {
         fd_table[i].dumpStats(*dumpEntry, i);
     }
 }
@@ -123,6 +124,6 @@ fde::remoteAddr() const
 void
 fde::noteUse(PconnPool *pool)
 {
-    pconn.uses++;
+    ++ pconn.uses;
     pconn.pool = pool;
 }
