@@ -1,6 +1,4 @@
 /*
- * $Id$
- *
  * DEBUG: section 79    Disk IO Routines
  */
 
@@ -13,6 +11,7 @@
 #include "fs/rock/RockIoState.h"
 #include "fs/rock/RockIoRequests.h"
 #include "fs/rock/RockSwapDir.h"
+#include "globals.h"
 
 Rock::IoState::IoState(SwapDir *dir,
                        StoreEntry *anEntry,
@@ -25,7 +24,7 @@ Rock::IoState::IoState(SwapDir *dir,
 {
     e = anEntry;
     // swap_filen, swap_dirn, diskOffset, and payloadEnd are set by the caller
-    slotSize = dir->max_objsize;
+    slotSize = dir->maxObjectSize();
     file_callback = cbFile;
     callback = cbIo;
     callback_data = cbdataReference(data);
@@ -193,7 +192,6 @@ private:
     Rock::IoState::Pointer sio;
 };
 
-
 void
 Rock::IoState::callBack(int errflag)
 {
