@@ -1,14 +1,11 @@
 /*
- * $Id$
- *
  * DEBUG: section 92    Storage File System
  */
 
-#include "config.h"
+#include "squid.h"
 #include "fs/rock/RockStoreFileSystem.h"
 #include "fs/rock/RockSwapDir.h"
 
-
 Rock::StoreFileSystem::StoreFileSystem()
 {
     FsAdd(*this);
