@@ -1,6 +1,4 @@
 /*
- * $Id$
- *
  * DEBUG: section 42    ICMP Pinger program
  * AUTHOR: Duane Wessels, Amos Jeffries
  *
@@ -33,47 +31,36 @@
  */
 //#define SQUID_HELPER 1
 
-#include "squid-old.h"
+#include "squid.h"
 
 #if USE_ICMP
 
+#include "leakcheck.h"
 #include "SquidTime.h"
 #include "Icmp4.h"
 #include "IcmpPinger.h"
 #include "Debug.h"
 
-static const char *
-IcmpPacketType(uint8_t v)
-{
-    static const char *icmpPktStr[] = {
-        "Echo Reply",
-        "ICMP 1",
-        "ICMP 2",
-        "Destination Unreachable",
-        "Source Quench",
-        "Redirect",
-        "ICMP 6",
-        "ICMP 7",
-        "Echo",
-        "ICMP 9",
-        "ICMP 10",
-        "Time Exceeded",
-        "Parameter Problem",
-        "Timestamp",
-        "Timestamp Reply",
-        "Info Request",
-        "Info Reply",
-        "Out of Range Type"
-    };
-
-    if (v > 17) {
-        static char buf[50];
-        snprintf(buf, sizeof(buf), "ICMP %u (invalid)", v);
-        return buf;
-    }
-
-    return icmpPktStr[v];
-}
+const char *icmpPktStr[] = {
+    "Echo Reply",
+    "ICMP 1",
+    "ICMP 2",
+    "Destination Unreachable",
+    "Source Quench",
+    "Redirect",
+    "ICMP 6",
+    "ICMP 7",
+    "Echo",
+    "ICMP 9",
+    "ICMP 10",
+    "Time Exceeded",
+    "Parameter Problem",
+    "Timestamp",
+    "Timestamp Reply",
+    "Info Request",
+    "Info Reply",
+    "Out of Range Type"
+};
 
 Icmp4::Icmp4() : Icmp()
 {
@@ -91,12 +78,12 @@ Icmp4::Open(void)
     icmp_sock = socket(PF_INET, SOCK_RAW, IPPROTO_ICMP);
 
     if (icmp_sock < 0) {
-        debugs(50, 0, HERE << " icmp_sock: " << xstrerror());
+        debugs(50, DBG_CRITICAL, HERE << " icmp_sock: " << xstrerror());
         return -1;
     }
 
     icmp_ident = getpid() & 0xffff;
-    debugs(42, 1, "pinger: ICMP socket opened.");
+    debugs(42, DBG_IMPORTANT, "pinger: ICMP socket opened.");
 
     return icmp_sock;
 }
@@ -164,7 +151,7 @@ Icmp4::SendEcho(Ip::Address &to, int opcode, const char *payload, int len)
                S->ai_addrlen);
 
     if (x < 0) {
-        debugs(42, 1, HERE << "Error sending to ICMP packet to " << to << ". ERR: " << xstrerror());
+        debugs(42, DBG_IMPORTANT, HERE << "Error sending to ICMP packet to " << to << ". ERR: " << xstrerror());
     }
 
     Log(to, ' ', NULL, 0, 0);
@@ -185,7 +172,7 @@ Icmp4::Recv(void)
     static pingerReplyData preply;
 
     if (icmp_sock < 0) {
-        debugs(42, 0, HERE << "No socket! Recv() should not be called.");
+        debugs(42, DBG_CRITICAL, HERE << "No socket! Recv() should not be called.");
         return;
     }
 
@@ -200,12 +187,6 @@ Icmp4::Recv(void)
                  from->ai_addr,
                  &from->ai_addrlen);
 
-    if (n <= 0) {
-        debugs(42, DBG_CRITICAL, HERE << "Error when calling recvfrom() on ICMP socket.");
-        Ip::Address::FreeAddrInfo(from);
-        return;
-    }
-
     preply.from = *from;
 
 #if GETTIMEOFDAY_NO_TZP
@@ -262,15 +243,9 @@ Icmp4::Recv(void)
 
     preply.psize = n - iphdrlen - (sizeof(icmpEchoData) - MAX_PKT4_SZ);
 
-    if (preply.psize < 0) {
-        debugs(42, DBG_CRITICAL, HERE << "Malformed ICMP packet.");
-        Ip::Address::FreeAddrInfo(from);
-        return;
-    }
-
     control.SendResult(preply, (sizeof(pingerReplyData) - MAX_PKT4_SZ + preply.psize) );
 
-    Log(preply.from, icmp->icmp_type, IcmpPacketType(icmp->icmp_type), preply.rtt, preply.hops);
+    Log(preply.from, icmp->icmp_type, icmpPktStr[icmp->icmp_type], preply.rtt, preply.hops);
     preply.from.FreeAddrInfo(from);
 }
 
