@@ -2,6 +2,7 @@
 #define SQUID_QOSCONFIG_H
 
 #include "hier_code.h"
+#include "ip/forward.h"
 
 #if HAVE_LIBNETFILTER_CONNTRACK_LIBNETFILTER_CONNTRACK_H
 #include <libnetfilter_conntrack/libnetfilter_conntrack.h>
@@ -15,9 +16,30 @@
 #include <limits>
 #endif
 
-// Forward-declaration
+class ACLList;
 class fde;
 
+// TODO: move to new ACL framework
+// not integrated in namespace, as this class uses a strange CBDATA definition
+// POD
+class acl_tos
+{
+public:
+    acl_tos *next;
+    ACLList *aclList;
+    tos_t tos;
+};
+// TODO: move to new ACL framework
+// not integrated in namespace, as this class uses a strange CBDATA definition
+// POD
+class acl_nfmark
+{
+public:
+    acl_nfmark *next;
+    ACLList *aclList;
+    nfmark_t nfmark;
+};
+
 namespace Ip
 {
 
@@ -32,20 +54,19 @@ namespace Qos
 * Function to retrieve the TOS value of the inbound packet.
 * Called by FwdState::dispatch if QOS options are enabled.
 * Bug 2537: This part of ZPH only applies to patched Linux kernels
-* @param server_fd Server side descriptor of connection to get TOS for
+* @param server    Server side descriptor of connection to get TOS for
 * @param clientFde Pointer to client side fde instance to set tosFromServer in
 */
-void getTosFromServer(const int server_fd, fde *clientFde);
+void getTosFromServer(const Comm::ConnectionPointer &server, fde *clientFde);
 
 /**
 * Function to retrieve the netfilter mark value of the connection
 * to the upstream server. Called by FwdState::dispatch if QOS
 * options are enabled.
-* @param server_fd Server side descriptor of connection to get mark for
-* @param servFde Pointer to server side fde instance to get mark for
+* @param server    Server side descriptor of connection to get mark for
 * @param clientFde Pointer to client side fde instance to set nfmarkFromServer in
 */
-void getNfmarkFromServer(const int server_fd, const fde *servFde, const fde *clientFde);
+void getNfmarkFromServer(const Comm::ConnectionPointer &server, const fde *clientFde);
 
 #if USE_LIBNETFILTERCONNTRACK
 /**
@@ -65,52 +86,52 @@ int getNfMarkCallback(enum nf_conntrack_msg_type type, struct nf_conntrack *ct,
 * TOS value to set on packets when items have not been retrieved from
 * local cache. Called by clientReplyContext::sendMoreData if QOS is
 * enabled for TOS.
-* @param fd Descriptor of socket to set the TOS for
+* @param conn     Descriptor of socket to set the TOS for
 * @param hierCode Hier code of request
 */
-int doTosLocalMiss(const int fd, const hier_code hierCode);
+int doTosLocalMiss(const Comm::ConnectionPointer &conn, const hier_code hierCode);
 
 /**
 * Function to work out and then apply to the socket the appropriate
 * netfilter mark value to set on packets when items have not been
 * retrieved from local cache. Called by clientReplyContext::sendMoreData
 * if QOS is enabled for TOS.
-* @param fd Descriptor of socket to set the mark for
+* @param conn     Descriptor of socket to set the mark for
 * @param hierCode Hier code of request
 */
-int doNfmarkLocalMiss(const int fd, const hier_code hierCode);
+int doNfmarkLocalMiss(const Comm::ConnectionPointer &conn, const hier_code hierCode);
 
 /**
 * Function to work out and then apply to the socket the appropriate
 * TOS value to set on packets when items *have* been retrieved from
 * local cache. Called by clientReplyContext::doGetMoreData if QOS is
 * enabled for TOS.
-* @param fd Descriptor of socket to set the TOS for
+* @param conn Descriptor of socket to set the TOS for
 */
-int doTosLocalHit(const int fd);
+int doTosLocalHit(const Comm::ConnectionPointer &conn);
 
 /**
 * Function to work out and then apply to the socket the appropriate
 * netfilter mark value to set on packets when items *have* been
 * retrieved from local cache. Called by clientReplyContext::doGetMoreData
 * if QOS is enabled for TOS.
-* @param fd Descriptor of socket to set the mark for
+* @param conn Descriptor of socket to set the mark for
 */
-int doNfmarkLocalHit(const int fd);
+int doNfmarkLocalHit(const Comm::ConnectionPointer &conn);
 
 /**
 * Function to set the TOS value of packets. Sets the value on the socket
 * which then gets copied to the packets.
-* @param fd Descriptor of socket to set the TOS for
+* @param conn Descriptor of socket to set the TOS for
 */
-_SQUID_INLINE_ int setSockTos(int fd, tos_t tos);
+_SQUID_INLINE_ int setSockTos(const Comm::ConnectionPointer &conn, tos_t tos);
 
 /**
 * Function to set the netfilter mark value of packets. Sets the value on the
 * socket which then gets copied to the packets. Called from Ip::Qos::doNfmarkLocalMiss
-* @param fd Descriptor of socket to set the mark for
+* @param conn Descriptor of socket to set the mark for
 */
-_SQUID_INLINE_ int setSockNfmark(int fd, nfmark_t mark);
+_SQUID_INLINE_ int setSockNfmark(const Comm::ConnectionPointer &conn, nfmark_t mark);
 
 /**
  * QOS configuration class. Contains all the parameters for QOS functions as well
@@ -158,15 +179,17 @@ public:
     tos_t tosSiblingHit;                ///< TOS value to apply to hits from siblings
     tos_t tosParentHit;                 ///< TOS value to apply to hits from parent
     tos_t tosMiss;                      ///< TOS value to apply to cache misses
+    tos_t tosMissMask;                  ///< Mask for TOS value to apply to cache misses. Applied to the tosMiss value.
     bool preserveMissTos;               ///< Whether to preserve the TOS value of the inbound packet for misses
-    tos_t preserveMissTosMask;          ///< The mask to apply when preserving the TOS of misses
+    tos_t preserveMissTosMask;          ///< The mask to apply when preserving the TOS of misses. Applies to preserved value from upstream.
 
     nfmark_t markLocalHit;              ///< Netfilter mark value to apply to local cache hits
     nfmark_t markSiblingHit;            ///< Netfilter mark value to apply to hits from siblings
     nfmark_t markParentHit;             ///< Netfilter mark value to apply to hits from parent
     nfmark_t markMiss;                  ///< Netfilter mark value to apply to cache misses
+    nfmark_t markMissMask;              ///< Mask for netfilter mark value to apply to cache misses. Applied to the markMiss value.
     bool preserveMissMark;              ///< Whether to preserve netfilter mark value of inbound connection
-    nfmark_t preserveMissMarkMask;      ///< The mask to apply when preserving the netfilter mark of misses
+    nfmark_t preserveMissMarkMask;      ///< The mask to apply when preserving the netfilter mark of misses. Applied to preserved value from upstream.
 
     acl_tos *tosToServer;               ///< The TOS that packets to the web server should be marked with, based on ACL
     acl_tos *tosToClient;               ///< The TOS that packets to the client should be marked with, based on ACL
