@@ -1,20 +1,18 @@
 /*
- * $Id$
- *
  * DEBUG: section 54    Interprocess Communication
  *
  */
 
-
 #include "squid.h"
-#include <string.h>
-#include "protos.h"
 #include "base/TextException.h"
 #include "ipc/TypedMsgHdr.h"
+#include "tools.h"
+
+#include <string.h>
 
 Ipc::TypedMsgHdr::TypedMsgHdr()
 {
-    xmemset(this, 0, sizeof(*this));
+    memset(this, 0, sizeof(*this));
     sync();
 }
 
@@ -60,8 +58,6 @@ void Ipc::TypedMsgHdr::sync()
     offset = 0;
 }
 
-
-
 int
 Ipc::TypedMsgHdr::type() const
 {
@@ -208,7 +204,7 @@ Ipc::TypedMsgHdr::getFd() const
 void
 Ipc::TypedMsgHdr::prepForReading()
 {
-    xmemset(this, 0, sizeof(*this));
+    memset(this, 0, sizeof(*this));
     allocName();
     allocData();
     allocControl();
