@@ -1,6 +1,4 @@
 /*
- * $Id$
- *
  * DEBUG: section 54    Interprocess Communication
  *
  */
@@ -13,6 +11,12 @@ namespace Ipc
 
 class TypedMsgHdr;
 class StrandCoord;
+class HereIamMessage;
+class StrandSearchResponse;
+class Forwarder;
+class Inquirer;
+class Request;
+class Response;
 
 } // namespace Ipc
 
