@@ -1,7 +1,5 @@
 
 /*
- * $Id$
- *
  *
  * SQUID Web Proxy Cache          http://www.squid-cache.org/
  * ----------------------------------------------------------
@@ -34,6 +32,8 @@
 #ifndef SQUID_MEM_NODE_H
 #define SQUID_MEM_NODE_H
 
+#include "defines.h"
+#include "MemPool.h"
 #include "StoreIOBuffer.h"
 #include "Range.h"
 
@@ -61,7 +61,7 @@ public:
     unsigned int write_pending:1;
 };
 
-MEMPROXY_CLASS_INLINE(mem_node)		/**DOCS_NOSEMI*/
+MEMPROXY_CLASS_INLINE(mem_node);
 
 inline std::ostream &
 operator << (std::ostream &os, mem_node &aNode)
