@@ -1,11 +1,9 @@
 /*
- * $Id$
- *
  * DEBUG: section 16    Cache Manager API
  *
  */
 
-#include "config.h"
+#include "squid.h"
 #include "base/TextException.h"
 #include "comm/Connection.h"
 #include "ipc/Messages.h"
@@ -13,7 +11,6 @@
 #include "mgr/ActionParams.h"
 #include "mgr/Request.h"
 
-
 Mgr::Request::Request(int aRequestorId, unsigned int aRequestId, const Comm::ConnectionPointer &aConn,
                       const ActionParams &aParams):
         Ipc::Request(aRequestorId, aRequestId),
