@@ -1,7 +1,4 @@
-
 /*
- * $Id$
- *
  * DEBUG: section 25    MiME Header Parsing
  * AUTHOR: Harvest Derived
  *
@@ -33,16 +30,11 @@
  *
  */
 
-#include "squid-old.h"
+#include "squid.h"
 
 #define GET_HDR_SZ 1024
-
-/* returns a pointer to a field-value of the first matching field-name */
-char *
-mime_get_header(const char *mime, const char *name)
-{
-    return mime_get_header_field(mime, name, NULL);
-}
+#include "Debug.h"
+#include "profiler/Profiler.h"
 
 /*
  * returns a pointer to a field-value of the first matching field-name where
@@ -117,6 +109,13 @@ mime_get_header_field(const char *mime, const char *name, const char *prefix)
     return NULL;
 }
 
+/* returns a pointer to a field-value of the first matching field-name */
+char *
+mime_get_header(const char *mime, const char *name)
+{
+    return mime_get_header_field(mime, name, NULL);
+}
+
 size_t
 headersEnd(const char *mime, size_t l)
 {
