@@ -1,7 +1,5 @@
 
 /*
- * $Id$
- *
  * DEBUG: section 72    Peer Digest Routines
  * AUTHOR: Alex Rousskov
  *
@@ -35,16 +33,23 @@
 
 #include "squid.h"
 #if USE_CACHE_DIGESTS
-
+#include "CacheDigest.h"
+#include "CachePeer.h"
 #include "event.h"
 #include "forward.h"
-#include "Store.h"
-#include "HttpRequest.h"
+#include "globals.h"
 #include "HttpReply.h"
+#include "HttpRequest.h"
+#include "internal.h"
 #include "MemObject.h"
+#include "neighbors.h"
+#include "mime_header.h"
 #include "PeerDigest.h"
 #include "SquidTime.h"
+#include "Store.h"
+#include "store_key_md5.h"
 #include "StoreClient.h"
+#include "tools.h"
 
 /* local types */
 
@@ -70,7 +75,6 @@ static void peerDigestFetchSetStats(DigestFetchState * fetch);
 static int peerDigestSetCBlock(PeerDigest * pd, const char *buf);
 static int peerDigestUseful(const PeerDigest * pd);
 
-
 /* local constants */
 Version const CacheDigestVer = { 5, 3 };
 
@@ -87,7 +91,7 @@ static time_t pd_last_req_time = 0;	/* last call to Check */
 
 /* initialize peer digest */
 static void
-peerDigestInit(PeerDigest * pd, peer * p)
+peerDigestInit(PeerDigest * pd, CachePeer * p)
 {
     assert(pd && p);
 
@@ -134,7 +138,7 @@ PeerDigest::operator delete (void *address)
 
 /* allocate new peer digest, call Init, and lock everything */
 PeerDigest *
-peerDigestCreate(peer * p)
+peerDigestCreate(CachePeer * p)
 {
     PeerDigest *pd;
     assert(p);
@@ -161,7 +165,7 @@ peerDigestDestroy(PeerDigest * pd)
      * tell it that the digest is gone.
      */
     if (cbdataReferenceValidDone(peerTmp, &p))
-        peerNoteDigestGone((peer *)p);
+        peerNoteDigestGone((CachePeer *)p);
 
     peerDigestClean(pd);
 
@@ -309,7 +313,7 @@ CBDATA_TYPE(DigestFetchState);
 static void
 peerDigestRequest(PeerDigest * pd)
 {
-    peer *p = pd->peer;
+    CachePeer *p = pd->peer;
     StoreEntry *e, *old_e;
     char *url;
     const cache_key *key;
@@ -343,9 +347,14 @@ peerDigestRequest(PeerDigest * pd)
 
     req->header.putStr(HDR_ACCEPT, "text/html");
 
-    if (p->login)
+    if (p->login &&
+            p->login[0] != '*' &&
+            strcmp(p->login, "PASS") != 0 &&
+            strcmp(p->login, "PASSTHRU") != 0 &&
+            strcmp(p->login, "NEGOTIATE") != 0 &&
+            strcmp(p->login, "PROXYPASS") != 0) {
         xstrncpy(req->login, p->login, MAX_LOGIN_SZ);
-
+    }
     /* create fetch state structure */
     CBDATA_INIT_TYPE(DigestFetchState);
 
@@ -405,7 +414,6 @@ peerDigestRequest(PeerDigest * pd)
                     peerDigestHandleReply, fetch);
 }
 
-
 /* Handle the data copying .. */
 
 /*
@@ -515,8 +523,6 @@ finish:
     cbdataReferenceDone(fetch);
 }
 
-
-
 /* wait for full http headers to be received then parse them */
 /*
  * This routine handles parsing the reply line.
@@ -634,7 +640,7 @@ peerDigestSwapInHeaders(void *data, char *buf, ssize_t size)
         assert (fetch->entry->getReply()->sline.status != 0);
 
         if (fetch->entry->getReply()->sline.status != HTTP_OK) {
-            debugs(72, 1, "peerDigestSwapInHeaders: " << fetch->pd->host <<
+            debugs(72, DBG_IMPORTANT, "peerDigestSwapInHeaders: " << fetch->pd->host <<
                    " status " << fetch->entry->getReply()->sline.status <<
                    " got cached!");
 
@@ -865,7 +871,6 @@ peerDigestReqFinish(DigestFetchState * fetch, char *buf,
         peerDigestFetchFinish(fetch, err);
 }
 
-
 /* destroys digest if peer disappeared
  * must be called only when fetch and pd cbdata are valid */
 static void
@@ -882,7 +887,7 @@ peerDigestPDFinish(DigestFetchState * fetch, int pcb_valid, int err)
     pd->stats.recv.msgs += fetch->recv.msg;
 
     if (err) {
-        debugs(72, 1, "" << (pcb_valid ? "temporary " : "" ) << "disabling (" << pd->req_result << ") digest from " << host);
+        debugs(72, DBG_IMPORTANT, "" << (pcb_valid ? "temporary " : "" ) << "disabling (" << pd->req_result << ") digest from " << host);
 
         if (pd->cd) {
             cacheDigestDestroy(pd->cd);
@@ -917,7 +922,7 @@ peerDigestFetchFinish(DigestFetchState * fetch, int err)
     assert(fetch->entry && fetch->request);
 
     if (fetch->old_entry) {
-        debugs(72, 2, "peerDigestFetchFinish: deleting old entry");
+        debugs(72, 3, "peerDigestFetchFinish: deleting old entry");
         storeUnregister(fetch->old_sc, fetch->old_entry, fetch);
         fetch->old_entry->releaseRequest();
         fetch->old_entry->unlock();
@@ -980,7 +985,6 @@ peerDigestFetchSetStats(DigestFetchState * fetch)
 
 }
 
-
 static int
 peerDigestSetCBlock(PeerDigest * pd, const char *buf)
 {
@@ -1007,14 +1011,14 @@ peerDigestSetCBlock(PeerDigest * pd, const char *buf)
     /* check version requirements (both ways) */
 
     if (cblock.ver.required > CacheDigestVer.current) {
-        debugs(72, 1, "" << host << " digest requires version " <<
+        debugs(72, DBG_IMPORTANT, "" << host << " digest requires version " <<
                cblock.ver.required << "; have: " << CacheDigestVer.current);
 
         return 0;
     }
 
     if (cblock.ver.current < CacheDigestVer.required) {
-        debugs(72, 1, "" << host << " digest is version " <<
+        debugs(72, DBG_IMPORTANT, "" << host << " digest is version " <<
                cblock.ver.current << "; we require: " <<
                CacheDigestVer.required);
 
@@ -1025,13 +1029,13 @@ peerDigestSetCBlock(PeerDigest * pd, const char *buf)
     if (cblock.ver.required > cblock.ver.current ||
             cblock.mask_size <= 0 || cblock.capacity <= 0 ||
             cblock.bits_per_entry <= 0 || cblock.hash_func_count <= 0) {
-        debugs(72, 0, "" << host << " digest cblock is corrupted.");
+        debugs(72, DBG_CRITICAL, "" << host << " digest cblock is corrupted.");
         return 0;
     }
 
     /* check consistency further */
     if ((size_t)cblock.mask_size != cacheDigestCalcMaskSize(cblock.capacity, cblock.bits_per_entry)) {
-        debugs(72, 0, host << " digest cblock is corrupted " <<
+        debugs(72, DBG_CRITICAL, host << " digest cblock is corrupted " <<
                "(mask size mismatch: " << cblock.mask_size << " ? " <<
                cacheDigestCalcMaskSize(cblock.capacity, cblock.bits_per_entry)
                << ").");
@@ -1040,7 +1044,7 @@ peerDigestSetCBlock(PeerDigest * pd, const char *buf)
 
     /* there are some things we cannot do yet */
     if (cblock.hash_func_count != CacheDigestHashFuncCount) {
-        debugs(72, 0, "" << host << " digest: unsupported #hash functions: " <<
+        debugs(72, DBG_CRITICAL, "" << host << " digest: unsupported #hash functions: " <<
                cblock.hash_func_count << " ? " << CacheDigestHashFuncCount << ".");
         return 0;
     }
@@ -1080,7 +1084,7 @@ peerDigestUseful(const PeerDigest * pd)
     const int bit_util = cacheDigestBitUtil(pd->cd);
 
     if (bit_util > 65) {
-        debugs(72, 0, "Warning: " << pd->host <<
+        debugs(72, DBG_CRITICAL, "Warning: " << pd->host <<
                " peer digest has too many bits on (" << bit_util << "%%).");
 
         return 0;
