@@ -1,6 +1,4 @@
 /*
- * $Id$
- *
  * DEBUG: section 00    Announcement Server
  * AUTHOR: Harvest Derived
  *
@@ -31,7 +29,7 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
  *
  */
-#include "config.h"
+#include "squid.h"
 
 #include <stdio.h>
 #include <fcntl.h>
@@ -76,7 +74,6 @@ sig_handle(int)
     exit(0);
 }
 
-
 int
 main(int argc, char *argv[])
 {
@@ -89,11 +86,10 @@ main(int argc, char *argv[])
     const char *logfile;
     char ip[4];
 
-    for (len = 0; len < 32; len++) {
+    for (len = 0; len < 32; ++len) {
         signal(len, sig_handle);
     }
 
-
     if (argc > 1)
         logfile = argv[1];
     else
@@ -109,7 +105,6 @@ main(int argc, char *argv[])
     close(2);
     dup(1);
 
-
     IPAddress ipa;
     chat tmp[MAX_HOSTNAMELEN];
     for (;;) {
