@@ -2,6 +2,8 @@
 #define _SQUID_SSL_ERROR_DETAIL_H
 
 #include "err_detail_type.h"
+#include "HttpRequest.h"
+#include "ErrorDetailManager.h"
 #include "ssl/support.h"
 #include "ssl/gadgets.h"
 
@@ -9,22 +11,22 @@
 #include <openssl/ssl.h>
 #endif
 
-// Custom SSL errors; assumes all official errors are positive
-#define SQUID_X509_V_ERR_DOMAIN_MISMATCH -1
-// All SSL errors range: from smallest (negative) custom to largest SSL error
-#define SQUID_SSL_ERROR_MIN SQUID_X509_V_ERR_DOMAIN_MISMATCH
-#define SQUID_SSL_ERROR_MAX INT_MAX
-
 namespace Ssl
 {
-/// Squid defined error code (<0),  an error code returned by SSL X509 api, or SSL_ERROR_NONE
-typedef int ssl_error_t;
+/**
+  \ingroup ServerProtocolSSLAPI
+ * Converts user-friendly error "name" into an Ssl::Errors list.
+ * The resulting list may have one or more elements, and needs to be
+ * released by the caller.
+ * This function can handle numeric error numbers as well as names.
+ */
+Ssl::Errors *ParseErrorString(const char *name);
 
 /**
    \ingroup ServerProtocolSSLAPI
- * The ssl_error_t representation of the error described by "name".
- */
-ssl_error_t ParseErrorString(const char *name);
+  * The ssl_error_t code of the error described by  "name".
+  */
+ssl_error_t GetErrorCode(const char *name);
 
 /**
    \ingroup ServerProtocolSSLAPI
@@ -46,12 +48,21 @@ const char *GetErrorDescr(ssl_error_t value);
 class ErrorDetail
 {
 public:
-    ErrorDetail(ssl_error_t err_no, X509 *cert);
+    // if broken certificate is nil, the peer certificate is broken
+    ErrorDetail(ssl_error_t err_no, X509 *peer, X509 *broken);
     ErrorDetail(ErrorDetail const &);
     const String &toString() const;  ///< An error detail string to embed in squid error pages
+    void useRequest(HttpRequest *aRequest) { if (aRequest != NULL) request = aRequest;}
     /// The error name to embed in squid error pages
     const char *errorName() const {return err_code();}
-
+    /// The error no
+    ssl_error_t errorNo() const {return error_no;}
+    ///Sets the low-level error returned by OpenSSL ERR_get_error()
+    void setLibError(unsigned long lib_err_no) {lib_error_no = lib_err_no;}
+    /// the peer certificate
+    X509 *peerCert() { return peer_cert.get(); }
+    /// peer or intermediate certificate that failed validation
+    X509 *brokenCert() {return broken_cert.get(); }
 private:
     typedef const char * (ErrorDetail::*fmt_action_t)() const;
     /**
@@ -72,13 +83,18 @@ private:
     const char *notafter() const;
     const char *err_code() const;
     const char *err_descr() const;
+    const char *err_lib_error() const;
 
     int convert(const char *code, const char **value) const;
     void buildDetail() const;
 
     mutable String errDetailStr; ///< Caches the error detail message
     ssl_error_t error_no;   ///< The error code
+    unsigned long lib_error_no; ///< low-level error returned by OpenSSL ERR_get_error(3SSL)
     X509_Pointer peer_cert; ///< A pointer to the peer certificate
+    X509_Pointer broken_cert; ///< A pointer to the broken certificate (peer or intermediate)
+    mutable ErrorDetailEntry detailEntry;
+    HttpRequest::Pointer request;
 };
 
 }//namespace Ssl
