@@ -1,7 +1,5 @@
 
 /*
- * $Id$
- *
  * DEBUG: section 90    Storage Manager Client-Side Interface
  * AUTHOR: Duane Wessels
  *
@@ -34,20 +32,24 @@
  * Portions copyright (c) 2003 Robert Collins <robertc@squid-cache.org>
  */
 
-#include "squid-old.h"
+#include "squid.h"
 #include "event.h"
+#include "HttpReply.h"
+#include "HttpRequest.h"
+#include "MemBuf.h"
+#include "MemObject.h"
+#include "mime_header.h"
+#include "profiler/Profiler.h"
+#include "SquidConfig.h"
+#include "StatCounters.h"
 #include "StoreClient.h"
 #include "Store.h"
-#include "HttpReply.h"
-#include "MemObject.h"
-#include "StatCounters.h"
+#include "store_swapin.h"
 #include "StoreMeta.h"
 #include "StoreMetaUnpacker.h"
 #if USE_DELAY_POOLS
 #include "DelayPools.h"
 #endif
-#include "HttpRequest.h"
-#include "MemBuf.h"
 
 /*
  * NOTE: 'Header' refers to the swapfile metadata header.
@@ -61,7 +63,7 @@ static StoreIOState::STRCB storeClientReadBody;
 static StoreIOState::STRCB storeClientReadHeader;
 static void storeClientCopy2(StoreEntry * e, store_client * sc);
 static EVH storeClientCopyEvent;
-static int CheckQuickAbort2(StoreEntry * entry);
+static bool CheckQuickAbortIsReasonable(StoreEntry * entry);
 static void CheckQuickAbort(StoreEntry * entry);
 
 CBDATA_CLASS_INIT(store_client);
@@ -412,7 +414,7 @@ store_client::startSwapin()
 
         return;
     } else {
-        debugs(90, 1, "WARNING: Averted multiple fd operation (1)");
+        debugs(90, DBG_IMPORTANT, "WARNING: Averted multiple fd operation (1)");
         flags.store_copying = 0;
         return;
     }
@@ -498,7 +500,7 @@ store_client::readBody(const char *buf, ssize_t len)
         HttpReply *rep = (HttpReply *) entry->getReply(); // bypass const
 
         if (!rep->parseCharBuf(copyInto.data, headersEnd(copyInto.data, len))) {
-            debugs(90, 0, "Could not parse headers from on disk object");
+            debugs(90, DBG_CRITICAL, "Could not parse headers from on disk object");
         } else {
             parsed_header = 1;
         }
@@ -571,7 +573,7 @@ store_client::unpackHeader(char const *buf, ssize_t len)
 
     if (!aBuilder.isBufferSane()) {
         /* oops, bad disk file? */
-        debugs(90, 1, "WARNING: swapfile header inconsistent with available data");
+        debugs(90, DBG_IMPORTANT, "WARNING: swapfile header inconsistent with available data");
         fail();
         return;
     }
@@ -579,7 +581,7 @@ store_client::unpackHeader(char const *buf, ssize_t len)
     tlv *tlv_list = aBuilder.createStoreMeta ();
 
     if (tlv_list == NULL) {
-        debugs(90, 1, "WARNING: failed to unpack meta data");
+        debugs(90, DBG_IMPORTANT, "WARNING: failed to unpack meta data");
         fail();
         return;
     }
@@ -781,72 +783,72 @@ storePendingNClients(const StoreEntry * e)
     return npend;
 }
 
-/* return 1 if the request should be aborted */
-static int
-CheckQuickAbort2(StoreEntry * entry)
+/* return true if the request should be aborted */
+static bool
+CheckQuickAbortIsReasonable(StoreEntry * entry)
 {
     MemObject * const mem = entry->mem_obj;
     assert(mem);
-    debugs(90, 3, "CheckQuickAbort2: entry=" << entry << ", mem=" << mem);
+    debugs(90, 3, "entry=" << entry << ", mem=" << mem);
 
     if (mem->request && !mem->request->flags.cachable) {
-        debugs(90, 3, "CheckQuickAbort2: YES !mem->request->flags.cachable");
-        return 1;
+        debugs(90, 3, "quick-abort? YES !mem->request->flags.cachable");
+        return true;
     }
 
     if (EBIT_TEST(entry->flags, KEY_PRIVATE)) {
-        debugs(90, 3, "CheckQuickAbort2: YES KEY_PRIVATE");
-        return 1;
+        debugs(90, 3, "quick-abort? YES KEY_PRIVATE");
+        return true;
     }
 
     int64_t expectlen = entry->getReply()->content_length + entry->getReply()->hdr_sz;
 
-    if (expectlen < 0)
+    if (expectlen < 0) {
         /* expectlen is < 0 if *no* information about the object has been received */
-        return 1;
-
-    int64_t curlen =  mem->endOffset ();
-
-    if (Config.quickAbort.min < 0) {
-        debugs(90, 3, "CheckQuickAbort2: NO disabled");
-        return 0;
+        debugs(90, 3, "quick-abort? YES no object data received yet");
+        return true;
     }
 
-    int64_t roffLimit = mem->request->getRangeOffsetLimit();
+    int64_t curlen =  mem->endOffset();
 
-    if ( roffLimit < 0 && mem->request && mem->request->range ) {
+    if (Config.quickAbort.min < 0) {
+        debugs(90, 3, "quick-abort? NO disabled");
+        return false;
+    }
+
+    if (mem->request && mem->request->range && mem->request->getRangeOffsetLimit() < 0) {
         /* Don't abort if the admin has configured range_ofset -1 to download fully for caching. */
-        debugs(90, 3, "CheckQuickAbort2: NO admin configured range replies to full-download");
-        return 0;
+        debugs(90, 3, "quick-abort? NO admin configured range replies to full-download");
+        return false;
     }
 
     if (curlen > expectlen) {
-        debugs(90, 3, "CheckQuickAbort2: YES bad content length");
-        return 1;
+        debugs(90, 3, "quick-abort? YES bad content length");
+        return true;
     }
 
     if ((expectlen - curlen) < (Config.quickAbort.min << 10)) {
-        debugs(90, 3, "CheckQuickAbort2: NO only little more left");
-        return 0;
+        debugs(90, 3, "quick-abort? NO only a little more object left to receive");
+        return false;
     }
 
     if ((expectlen - curlen) > (Config.quickAbort.max << 10)) {
-        debugs(90, 3, "CheckQuickAbort2: YES too much left to go");
-        return 1;
+        debugs(90, 3, "quick-abort? YES too much left to go");
+        return true;
     }
 
     if (expectlen < 100) {
-        debugs(90, 3, "CheckQuickAbort2: NO avoid FPE");
-        return 0;
+        debugs(90, 3, "quick-abort? NO avoid FPE");
+        return false;
     }
 
     if ((curlen / (expectlen / 100)) > (Config.quickAbort.pct)) {
-        debugs(90, 3, "CheckQuickAbort2: NO past point of no return");
-        return 0;
+        debugs(90, 3, "quick-abort? NO past point of no return");
+        return false;
     }
 
-    debugs(90, 3, "CheckQuickAbort2: YES default, returning 1");
-    return 1;
+    debugs(90, 3, "quick-abort? YES default");
+    return true;
 }
 
 static void
@@ -863,7 +865,7 @@ CheckQuickAbort(StoreEntry * entry)
     if (EBIT_TEST(entry->flags, ENTRY_SPECIAL))
         return;
 
-    if (CheckQuickAbort2(entry) == 0)
+    if (!CheckQuickAbortIsReasonable(entry))
         return;
 
     entry->abort();
